==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfStyledFieldWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStyledFieldWidget (  PdfFieldWidget) :
    """
    Represents loaded styled field.
    """
    @property

    def Actions(self)->'PdfFieldActions':
        """
        Gets the actions of the field.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Actions.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Actions.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_Actions(self.Ptr)
        ret = None if intPtr==None else PdfFieldActions(intPtr)
        return ret


    @property

    def MouseEnter(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseEnter.setter
    def MouseEnter(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseEnter.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseEnter(self.Ptr, value.Ptr)

    @property

    def MouseUp(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is released 
            inside the annotations active area..
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseUp.setter
    def MouseUp(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseUp.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseUp(self.Ptr, value.Ptr)

    @property

    def MouseDown(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is pressed inside the 
            annotations active area.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseDown.setter
    def MouseDown(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseDown.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseDown(self.Ptr, value.Ptr)

    @property

    def MouseLeave(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseLeave.setter
    def MouseLeave(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseLeave.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseLeave(self.Ptr, value.Ptr)

    @property

    def GotFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the annotation receives the 
            input focus.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @GotFocus.setter
    def GotFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_GotFocus.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_GotFocus(self.Ptr, value.Ptr)

    @property

    def ForeColor(self)->'PdfRGBColor':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @ForeColor.setter
    def ForeColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_ForeColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_ForeColor(self.Ptr, value.Ptr)

    @property

    def BackColor(self)->'PdfRGBColor':
        """
        Get or Set the background color of the field
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BackColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BackColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_BackColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BackColor.setter
    def BackColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BackColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_BackColor(self.Ptr, value.Ptr)

    @property

    def LostFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the annotation loses the 
            input focus.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @LostFocus.setter
    def LostFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_LostFocus.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_LostFocus(self.Ptr, value.Ptr)

    @property

    def Bounds(self)->'RectangleF':
        """
        Gets or sets the bounds.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Bounds.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Bounds.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_Bounds(self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @Bounds.setter
    def Bounds(self, value:'RectangleF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Bounds.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_Bounds(self.Ptr, value.Ptr)

    @property

    def Location(self)->'PointF':
        """
        Gets or sets the location.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Location.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Location.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_Location(self.Ptr)
        ret = None if intPtr==None else PointF(intPtr)
        return ret


    @Location.setter
    def Location(self, value:'PointF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Location.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_Location(self.Ptr, value.Ptr)

    @property

    def Size(self)->'SizeF':
        """
        Gets or sets the size.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Size.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Size.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_Size(self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @Size.setter
    def Size(self, value:'SizeF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Size.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_Size(self.Ptr, value.Ptr)

    @property

    def BorderStyle(self)->'PdfBorderStyle':
        """
        Gets or sets the color of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle.restype=c_int
        ret = GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle(self.Ptr)
        objwraped = PdfBorderStyle(ret)
        return objwraped

    @BorderStyle.setter
    def BorderStyle(self, value:'PdfBorderStyle'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderStyle.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderStyle(self.Ptr, value.value)

    @property

    def BorderColor(self)->'PdfRGBColor':
        """
        Gets or sets the color of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BorderColor.setter
    def BorderColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderColor(self.Ptr, value.Ptr)

    @property
    def BorderWidth(self)->float:
        """
        Gets or Sets the width of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth.restype=c_float
        ret = GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth(self.Ptr)
        return ret

    @BorderWidth.setter
    def BorderWidth(self, value:float):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderWidth.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderWidth(self.Ptr, value)

    @property

    def Font(self)->'PdfFontBase':
        """
        Gets the font.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Font.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Font.restype=c_void_p
        intPtr = GetDllLibPdf().PdfStyledFieldWidget_get_Font(self.Ptr)
        ret = None if intPtr==None else PdfFontBase(intPtr)
        return ret


    @Font.setter
    def Font(self, value:'PdfFontBase'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Font.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_set_Font(self.Ptr, value.Ptr)

    @property
    def DefaultIndex(self)->int:
        """
        Gets the default index.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex.restype=c_int
        ret = GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex(self.Ptr)
        return ret

    @DefaultIndex.setter
    def DefaultIndex(self, value:int):
        GetDllLibPdf().PdfStyledFieldWidget_set_DefaultIndex.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfStyledFieldWidget_set_DefaultIndex(self.Ptr, value)

    @property
    def Visible(self)->bool:
        """
        Gets a value indicating the visibility of the field.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Visible.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Visible.restype=c_bool
        ret = GetDllLibPdf().PdfStyledFieldWidget_get_Visible(self.Ptr)
        return ret

    def ObjectID(self)->int:
        """
        Form field identifier
        """
        GetDllLibPdf().PdfStyledFieldWidget_ObjectID.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_ObjectID.restype=c_int
        ret = GetDllLibPdf().PdfStyledFieldWidget_ObjectID(self.Ptr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfStyledFieldWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStyledFieldWidget (  PdfFieldWidget) :
    """
    Represents loaded styled field.
    """
    @property

    def Actions(self)->'PdfFieldActions':
        """
        Gets the actions of the field.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Actions.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Actions.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Actions,self.Ptr)
        ret = None if intPtr==None else PdfFieldActions(intPtr)
        return ret


    @property

    def MouseEnter(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_MouseEnter,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseEnter.setter
    def MouseEnter(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseEnter.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_MouseEnter,self.Ptr, value.Ptr)

    @property

    def MouseUp(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is released 
            inside the annotations active area..
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_MouseUp,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseUp.setter
    def MouseUp(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseUp.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_MouseUp,self.Ptr, value.Ptr)

    @property

    def MouseDown(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is pressed inside the 
            annotations active area.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_MouseDown,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseDown.setter
    def MouseDown(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseDown.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_MouseDown,self.Ptr, value.Ptr)

    @property

    def MouseLeave(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_MouseLeave,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseLeave.setter
    def MouseLeave(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_MouseLeave.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_MouseLeave,self.Ptr, value.Ptr)

    @property

    def GotFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the annotation receives the 
            input focus.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_GotFocus,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @GotFocus.setter
    def GotFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_GotFocus.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_GotFocus,self.Ptr, value.Ptr)

    @property

    def ForeColor(self)->'PdfRGBColor':
        """

        """
        GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_ForeColor,self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @ForeColor.setter
    def ForeColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_ForeColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_ForeColor,self.Ptr, value.Ptr)

    @property

    def BackColor(self)->'PdfRGBColor':
        """
        Get or Set the background color of the field
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BackColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BackColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_BackColor,self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BackColor.setter
    def BackColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BackColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_BackColor,self.Ptr, value.Ptr)

    @property

    def LostFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the annotation loses the 
            input focus.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_LostFocus,self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @LostFocus.setter
    def LostFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfStyledFieldWidget_set_LostFocus.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_LostFocus,self.Ptr, value.Ptr)

    @property

    def Bounds(self)->'RectangleF':
        """
        Gets or sets the bounds.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Bounds.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Bounds.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Bounds,self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @Bounds.setter
    def Bounds(self, value:'RectangleF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Bounds.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_Bounds,self.Ptr, value.Ptr)

    @property

    def Location(self)->'PointF':
        """
        Gets or sets the location.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Location.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Location.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Location,self.Ptr)
        ret = None if intPtr==None else PointF(intPtr)
        return ret


    @Location.setter
    def Location(self, value:'PointF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Location.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_Location,self.Ptr, value.Ptr)

    @property

    def Size(self)->'SizeF':
        """
        Gets or sets the size.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Size.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Size.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Size,self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @Size.setter
    def Size(self, value:'SizeF'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Size.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_Size,self.Ptr, value.Ptr)

    @property

    def BorderStyle(self)->'PdfBorderStyle':
        """
        Gets or sets the color of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_BorderStyle,self.Ptr)
        objwraped = PdfBorderStyle(ret)
        return objwraped

    @BorderStyle.setter
    def BorderStyle(self, value:'PdfBorderStyle'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderStyle.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_BorderStyle,self.Ptr, value.value)

    @property

    def BorderColor(self)->'PdfRGBColor':
        """
        Gets or sets the color of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_BorderColor,self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BorderColor.setter
    def BorderColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderColor.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_BorderColor,self.Ptr, value.Ptr)

    @property
    def BorderWidth(self)->float:
        """
        Gets or Sets the width of the border.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth.restype=c_float
        ret = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_BorderWidth,self.Ptr)
        return ret

    @BorderWidth.setter
    def BorderWidth(self, value:float):
        GetDllLibPdf().PdfStyledFieldWidget_set_BorderWidth.argtypes=[c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_BorderWidth,self.Ptr, value)

    @property

    def Font(self)->'PdfFontBase':
        """
        Gets the font.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Font.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Font.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Font,self.Ptr)
        ret = None if intPtr==None else PdfFontBase(intPtr)
        return ret


    @Font.setter
    def Font(self, value:'PdfFontBase'):
        GetDllLibPdf().PdfStyledFieldWidget_set_Font.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_Font,self.Ptr, value.Ptr)

    @property
    def DefaultIndex(self)->int:
        """
        Gets the default index.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_DefaultIndex,self.Ptr)
        return ret

    @DefaultIndex.setter
    def DefaultIndex(self, value:int):
        GetDllLibPdf().PdfStyledFieldWidget_set_DefaultIndex.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_set_DefaultIndex,self.Ptr, value)

    @property
    def Visible(self)->bool:
        """
        Gets a value indicating the visibility of the field.
        """
        GetDllLibPdf().PdfStyledFieldWidget_get_Visible.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_get_Visible.restype=c_bool
        ret = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_get_Visible,self.Ptr)
        return ret

    def ObjectID(self)->int:
        """
        Form field identifier
        """
        GetDllLibPdf().PdfStyledFieldWidget_ObjectID.argtypes=[c_void_p]
        GetDllLibPdf().PdfStyledFieldWidget_ObjectID.restype=c_int
        ret = CallCFunction(GetDllLibPdf().PdfStyledFieldWidget_ObjectID,self.Ptr)
        return ret
